;; Enhancement of lpr.el
;; Coded by K.Handa, Electrotechnical Lab. (handa@etl.go.jp)

;; This file is part of Nemacs (Japanese version of GNU Emacs).

;; Nemacs is distributed in the forms of patches to GNU
;; Emacs under the terms of the GNU EMACS GENERAL PUBLIC
;; LICENSE which is distributed along with GNU Emacs by the
;; Free Software Foundation.

;; Nemacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied
;; warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
;; PURPOSE.  See the GNU EMACS GENERAL PUBLIC LICENSE for
;; more details.

;; You should have received a copy of the GNU EMACS GENERAL
;; PUBLIC LICENSE along with Nemacs; see the file COPYING.
;; If not, write to the Free Software Foundation, 675 Mass
;; Ave, Cambridge, MA 02139, USA.

;;; 89.3.15  created by K.Handa

(defconst lpr-printer-list '(("minec") ("milw") ("misony") ("clslw"))
  "Alist whose elements' cars are printer-names.\n\
The first one is a default printer.")

(defconst lpr-last-used-printer (car (car lpr-printer-list))
  "Place to hold printer name which was used last time.")

(defun lpr-whole-buffer (region printer)
  "Send whole buffer to PRINTER by 'lpr -P???' command.\n\
If any argument, only the current region is sent."
  (interactive
   (list
    (if current-prefix-arg
	(let ((m (mark)) (p (point)))
	  (if (< m p) (cons m p) (cons p m))))
    (completing-read "Printer: "
		     lpr-printer-list
		     nil nil
		     lpr-last-used-printer)))
  (setq lpr-last-used-printer printer)
  (let ((lpr-switches (list (concat "-P" printer))))
    (if region
	(lpr-region (car region) (cdr region))
      (lpr-buffer))))

(global-set-key "\C-xl" 'lpr-whole-buffer) ; originally count-lines-page
