;; Miscellaneous small functions
;; Coded by K.Handa, Electrotechnical Lab. (handa@etl.go.jp)
;;      and S.Tomura, Electrotechnical Lab. (tomura@etl.go.jp)

;; This file is part of Nemacs (Japanese version of GNU Emacs).

;; Nemacs is distributed in the forms of patches to GNU
;; Emacs under the terms of the GNU EMACS GENERAL PUBLIC
;; LICENSE which is distributed along with GNU Emacs by the
;; Free Software Foundation.

;; Nemacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied
;; warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
;; PURPOSE.  See the GNU EMACS GENERAL PUBLIC LICENSE for
;; more details.

;; You should have received a copy of the GNU EMACS GENERAL
;; PUBLIC LICENSE along with Nemacs; see the file COPYING.
;; If not, write to the Free Software Foundation, 675 Mass
;; Ave, Cambridge, MA 02139, USA.

;;; 90.3.3  created by K.Handa

;;; X FONT

(defvar x-font-alist
  '(("a14" . "k14")
    ("a16" . "k16")
    ("a24" . "k24")
    ("rom-a14" . "rom-k14")
    ("rom-a16" . "rom-k16")
    ("rom-a24" . "rom-k24")))

(defun x-change-font (font)
  "Change font and kfont to FONT and its correspondence."
  (interactive "sASCII font name: ")
  (x-set-font (car (assoc font x-font-alist)))
  (x-set-kfont (cdr (assoc font x-font-alist))))

;;; MAIL

(setq mail-setup-hook 'mail-setup-for-mailing-list)

(defvar mail-mailing-list-list
  nil
  "*List of names of mailing lists to be recognized by\n\
'mail-setup-for-mailing-list'.")

(defun mail-setup-for-mailing-list ()
  "Set up fields when reply to mailing list."
  (if mail-mailing-list-list
      (progn
	(let ((list mail-mailing-list-list)
	      (to-and-cc (concat (mail-fetch-field "to")
				 (mail-fetch-field "cc"))))
	  (while list
	    (if (string-match (car list) to-and-cc)
		(progn
		  (if (mail-position-on-field "to" t)
		      (progn
			(forward-char 1)
			(zap-to-char -2 ?\n)))
		  (if (mail-position-on-field "cc" t)
		      (progn
			(forward-char 1)
			(zap-to-char -2 ?\n)))
		  (if (mail-position-on-field "reply-to" t)
		      (progn
			(forward-char 1)
			(zap-to-char -2 ?\n)))
		  (insert "To: " (car list) ?\n "Reply-to: " (car list) ?\n)
		  (goto-char (point-max))
		  (setq list nil)))
	    (setq list (cdr list))))
	))
  )

(global-set-key "\er" 'rmail)

;;; EGG

(defun set-attribute-for-egg ()
  "Set attributes to use EGG with proper style."
  (interactive)
  (if window-system
      (progn
	(require 'attribute)
	(set-egg-fence-mode-format "" "" 'underline)
	(set-egg-henkan-mode-format "" "" "" 'underline 'inverse))
    (set-egg-fence-mode-format "|" "|")
    (set-egg-henkan-mode-format "|" "|" " ")))

(set-attribute-for-egg)

;;; Caution!  The following feature will be change in the near future.
(setq-default mode-line-egg-mode "--")
(setq mode-line-egg-mode "--")
(setq mode-line-egg-mode-in-minibuffer "--")
(egg:set-mode-indicator "roma-kana" "")
(setq-default egg:*current-mode* (egg:get-mode-indicator "roma-kana"))
(setq egg:*current-mode* (egg:get-mode-indicator "roma-kana"))
(setq alphabet-mode-indicator "aA")
(setq transparent-mode-indicator "--")
(setq henkan-mode-indicator "")
